componenttools.ContainmentSignature
===================================

.. abjad-lineage:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature

.. autoclass:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__eq__
   :noindex:

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__ge__
   :noindex:

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__gt__
   :noindex:

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__le__
   :noindex:

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__lt__
   :noindex:

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__ne__
   :noindex:

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__repr__
   :noindex:

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__str__
   :noindex:
